===================
argus-HTMx-frontend
===================

This frontend has been merged into `argus-server`_, as a django app.

See `argus-server`_ for more about argus.

Imports `django-htmx`_. See the `documentation for django-htmx`_
for details.

.. attention::

   This repo is has been merged into the repo at `argus-server`_.

   This is the final release, to update the README before archiving everything.

.. _django-htmx: https://github.com/adamchainz/django-htmx
.. _argus-server: https://github.com/Uninett/Argus
.. _documentation for django-htmx: https://django-htmx.readthedocs.io/en/latest/
